==> efax-gtk-3.0.0.src.tgz: efax-gtk-3.0.0/src/selected_rows_handle.cpp <==
/* Copyright (C) 2004 and 2005 Chris Vine

This program is distributed under the General Public Licence, version 2.
For particulars of this and relevant disclaimers see the file
COPYING distributed with the source files.

*/

#include <algorithm>

#include <gtk/gtktreeselection.h>
#include "selected_rows_handle.h"


namespace { // callback for internal use only
void SelectedRowsHandleCB::selected_rows_handle_fill_cb(GtkTreeModel*,
							GtkTreePath* path_p,
							GtkTreeIter*,
							void* data) {
  SelectedRowsHandle* instance_p = static_cast<SelectedRowsHandle*>(data);
  instance_p->path_list.push_back(TreePathSharedHandle(gtk_tree_path_copy(path_p)));
}
}  // anonymous namespace


// this is a functor for converting a TreePathSharedHandle to a TreeRowRefSharedHandle
// and is suitable for use with std::transform()
class PathToRowRef {
  GobjHandle<GtkTreeModel> model_h;
public:
  TreeRowRefSharedHandle operator()(const TreePathSharedHandle& path_h) {
    return TreeRowRefSharedHandle(gtk_tree_row_reference_new(model_h, path_h));
  }
  PathToRowRef(GobjHandle<GtkTreeModel> model_h_): model_h(model_h_) {}
};

void SelectedRowsHandle::fill(const GtkTreeView* tree_view_p) {

  path_list.clear();

  GtkTreeSelection* selection_p =
    gtk_tree_view_get_selection(const_cast<GtkTreeView*>(tree_view_p));
  gtk_tree_selection_selected_foreach(selection_p,
				      SelectedRowsHandleCB::selected_rows_handle_fill_cb,
				      this);
}

void SelectedRowsHandle::get_ref_list(GobjHandle<GtkTreeModel> model_h,
				      RowRefList& row_ref_list) const {

  row_ref_list.clear();
  std::transform(path_list.begin(), path_list.end(),
		 std::back_inserter(row_ref_list), PathToRowRef(model_h));
}

==> efax-gtk-3.0.2.src.tgz: efax-gtk-3.0.2/src/selected_rows_handle.cpp <==
/* Copyright (C) 2004 and 2005 Chris Vine

This program is distributed under the General Public Licence, version 2.
For particulars of this and relevant disclaimers see the file
COPYING distributed with the source files.

*/

#include <algorithm>

#include <gtk/gtktreeselection.h>
#include "selected_rows_handle.h"


namespace { // callback for internal use only
void SelectedRowsHandleCB::selected_rows_handle_fill_cb(GtkTreeModel*,
							GtkTreePath* path_p,
							GtkTreeIter*,
							void* data) {
  SelectedRowsHandle* instance_p = static_cast<SelectedRowsHandle*>(data);
  instance_p->path_list.push_back(TreePathSharedHandle(gtk_tree_path_copy(path_p)));
}
}  // anonymous namespace


// this is a functor for converting a TreePathSharedHandle to a TreeRowRefSharedHandle
// and is suitable for use with std::transform()
class PathToRowRef {
  GtkTreeModel* model_p;
public:
  TreeRowRefSharedHandle operator()(const TreePathSharedHandle& path_h) {
    return TreeRowRefSharedHandle(gtk_tree_row_reference_new(model_p, path_h));
  }
  PathToRowRef(GtkTreeModel* model_p_): model_p(model_p_) {}
};

void SelectedRowsHandle::fill(const GtkTreeView* tree_view_p) {

  path_list.clear();

  GtkTreeSelection* selection_p =
    gtk_tree_view_get_selection(const_cast<GtkTreeView*>(tree_view_p));
  gtk_tree_selection_selected_foreach(selection_p,
				      SelectedRowsHandleCB::selected_rows_handle_fill_cb,
				      this);
}

void SelectedRowsHandle::get_ref_list(GtkTreeModel* model_p,
				      RowRefList& row_ref_list) const {

  row_ref_list.clear();
  std::transform(path_list.begin(), path_list.end(),
		 std::back_inserter(row_ref_list), PathToRowRef(model_p));
}
